@@ -1,7 +1,4 @@
-#![cfg(all(
-    any(feature = "2d", feature = "3d"),
-    not(all(feature = "2d", feature = "3d")),
-))]
+#![cfg(any(dim2, dim3))]
 
 use bevy::app::prelude::*;
 use bevy::core::CorePlugin;
@@ -10,9 +7,10 @@ use bevy::reflect::TypeRegistryArc;
 
 use heron_core::Gravity;
 use heron_core::PhysicsTime;
-use heron_rapier::rapier::dynamics::{IntegrationParameters, JointSet, RigidBodySet};
-use heron_rapier::rapier::geometry::ColliderSet;
 use heron_rapier::RapierPlugin;
+use utils::*;
+
+mod utils;
 
 #[test]
 fn can_define_gravity_before_plugin() {
